[−][src]Module httlib_huffman::decode
This module provides an implementation of the canonical Huffman decoder.
Modules
| table4 |
Enums
| DecoderError | An object returned by the decode function when an error occurs. |
Functions
| decode | Decodes Huffman's sequence from the provided table. The table design explains how many bits should be read at the time. |