[−][src]Module httlib_huffman::encode::table
Constants
| ENCODE_TABLE | This is a static Huffman table built from the codes found in the official HPACK specification (Appendix B). |
| ENCODE_TABLE | This is a static Huffman table built from the codes found in the official HPACK specification (Appendix B). |