[][src]Module httlib_huffman::flatten

This module provides features for flattening Huffman tree and generating translation matrixs.

Functions

flatten

Generates a translation matrix that can be used to decode a decoded content. The function expects the speed attribute which represents the number of bits that the decoder will read at a time when decoding an encoded sequence. The speed attribute can be between 1 bit and 5 bits. The higher number will have a positive effect on performance but a higher more footprint.