[−][src]Module httlib_huffman::flatten
This module provides features for flattening Huffman tree and generating translation matrixs.
Functions
| flatten | Generates a translation matrix that can be used to decode a decoded content.
The function expects the |